from django.apps import AppConfig


class MetainfoConfig(AppConfig):
    name = "apis_core.apis_metainfo"
